@@ -15,7 +15,7 @@ import numpy as np
 from sklearn.base import BaseEstimator, is_classifier
 from sklearn.base import MetaEstimatorMixin
 from sklearn.base import clone
-from sklearn.feature_selection.base import SelectorMixin
+from sklearn.feature_selection._base import SelectorMixin
 from sklearn.metrics import check_scoring
 from sklearn.model_selection import check_cv
 from sklearn.model_selection._validation import _score, cross_val_score
