@@ -17,10 +17,11 @@ from collections.abc import Iterable
 
 import numpy as np
 import sympy
+from sklearn.metrics import r2_score
 from sklearn.utils import check_X_y, check_array
 
 from featurebox.symbol.calculation.scores import calcualte_dim_score, \
-    calculate_collect, compile_context, calculate_cv_score
+    calculate_collect, compile_context, calculate_cv_score, score_collection
 from featurebox.symbol.calculation.translate import group_str
 from featurebox.symbol.functions.dimfunc import dim_map, Dim, dnan, dless
 from featurebox.symbol.functions.gsymfunc import gsym_map, NewArray
@@ -806,7 +807,8 @@ class SymbolSet(object):
         if isinstance(feature_name, list):
             for i, j in enumerate(feature_name):
                 self.terminals_fea_map["x%s" % i] = j
-
+        if x_group is None:
+            x_group = [[]]
         self.x_group = x_group
         self._group(x_group)
 
@@ -1282,7 +1284,7 @@ class CalculatePrecisionSet(SymbolSet):
         self.cal_dim = cal_dim
         self.score_pen = score_pen
         self.filter_warning = filter_warning
-        self.scoring = scoring
+
         self.add_coef = add_coef
         self.inter_add = inter_add
         self.inner_add = inner_add
@@ -1297,6 +1299,15 @@ class CalculatePrecisionSet(SymbolSet):
         self.refit = True
         self.cv = cv
 
+        if not scoring:
+            scoring = [r2_score, ]
+        if not isinstance(scoring, (tuple, list)):
+            scoring = [scoring, ]
+
+        scoring = [score_collection[i] if isinstance(i, str) else i for i in scoring]
+
+        self.scoring = scoring
+
     def calculate_cv_score(self, ind):
         if isinstance(ind, SymbolTree):
             expr = compile_context(ind.capsule, self.context, self.gro_ter_con)
