@@ -91,7 +91,11 @@ class BaseLoop(Toolbox):
         inter_add：bool
             add intercept constant or not
         inner_add:bool
-            dd inner coeffcients or not
+            add inner coeffcients or not
+        out_add:bool
+            add out coeffcients or not
+        flat_add:bool
+            add flat coeffcients or not
         n_jobs:int
             default 1, advise 6
         batch_size:int
