@@ -404,6 +404,9 @@ def mutDifferentReplacementVerbose(individual, pset, personal_map=False):
     cou_mutil = {i: j for i, j in cou.items() if j >= 2}
     ks = list(cou_mutil.keys())
     nks = list(set(pset_ters) - (set(ks)))
+    if len(nks) <= 1:
+        return individual,
+
     nks.sort()  # very import for random
 
     p_nks = np.array([pset.prob_ter_con[i] for i in nks])
@@ -548,7 +551,7 @@ def Statis_func(stats=None):
     if stats is None:
         stats = {"fitness_dim_max": ("max",), "dim_is_target": ("sum",)}
 
-    func = {"max": np.max, "mean": np.mean, "min": np.mean, "std": np.std, "sum": np.sum}
+    func = {"max": np.max, "mean": np.mean, "min": np.min, "std": np.std, "sum": np.sum}
     att = {
 
         "fitness": lambda ind: ind.fitness.values[0],
