@@ -1,11 +1,11 @@
 import unittest
 
 import numpy
-from featurebox.symbol.functions.dimfunc import dless, Dim
 
 from featurebox.symbol.base import CalculatePrecisionSet
 from featurebox.symbol.base import SymbolSet
 from featurebox.symbol.base import SymbolTree
+from featurebox.symbol.functions.dimfunc import dless
 
 
 class MyTestbase(unittest.TestCase):
